@@ -5,6 +5,7 @@ import { Combobox, Field, Input, Stack } from '@grafana/ui';
 
 import { FreeTierLimitNote } from '../Shared/FreeTierLimitNote';
 import { useBranchOptions } from '../hooks/useBranchOptions';
+import { useGetRepositoryRefs } from '../hooks/useGetRepositoryRefs';
 import { isGitProvider } from '../utils/repositoryTypes';
 
 import { RepositoryField } from './components/RepositoryField';
@@ -23,13 +24,16 @@ export const ConnectStep = memo(function ConnectStep() {
 
   // We don't need to dynamically react on repo type changes, so we use getValues for it
   const type = getValues('repository.type');
-  const [repositoryUrl = '', repositoryToken = '', repositoryTokenUser = ''] = watch([
+  const [repositoryUrl = '', repositoryToken = '', repositoryTokenUser = '', repositoryName = ''] = watch([
     'repository.url',
     'repository.token',
     'repository.tokenUser',
+    'repositoryName',
   ]);
   const isGitBased = isGitProvider(type);
+  const isGithubType = type === 'github';
 
+  // this hook fetches branches directly from the git provider
   const {
     options: branchOptions,
     loading: branchesLoading,
@@ -41,6 +45,19 @@ export const ConnectStep = memo(function ConnectStep() {
     repositoryTokenUser,
   });
 
+  // this hook returns branches from internal endpoint (only available for Github PAT and Github App)
+  const {
+    options: repositoryRefsOptions,
+    loading: isRefsLoading,
+    error: refsError,
+  } = useGetRepositoryRefs({
+    repositoryType: type,
+    repositoryName: isGithubType ? repositoryName : undefined,
+  });
+
+  const branches = isGithubType ? repositoryRefsOptions : branchOptions;
+  const isBranchesLoading = isGithubType ? isRefsLoading : branchesLoading;
+  const branchesErrorMsg = isGithubType ? refsError : branchesError;
   const gitFields = isGitBased ? getGitProviderFields(type) : null;
   const localFields = !isGitBased ? getLocalProviderFields(type) : null;
 
@@ -59,9 +76,9 @@ export const ConnectStep = memo(function ConnectStep() {
             noMargin
             label={gitFields.branchConfig.label}
             description={gitFields.branchConfig.description}
-            error={errors?.repository?.branch?.message}
+            error={errors?.repository?.branch?.message || branchesErrorMsg}
             required={gitFields.branchConfig.required}
-            invalid={Boolean(errors?.repository?.branch?.message || branchesError)}
+            invalid={Boolean(errors?.repository?.branch?.message || branchesErrorMsg)}
           >
             <Controller
               name="repository.branch"
@@ -69,11 +86,11 @@ export const ConnectStep = memo(function ConnectStep() {
               rules={gitFields.branchConfig.validation}
               render={({ field: { ref, onChange, ...field } }) => (
                 <Combobox
-                  invalid={Boolean(errors?.repository?.branch?.message || branchesError)}
+                  invalid={Boolean(errors?.repository?.branch?.message || branchesErrorMsg)}
                   onChange={(option) => onChange(option?.value || '')}
                   placeholder={gitFields.branchConfig.placeholder}
-                  options={branchOptions}
-                  loading={branchesLoading}
+                  options={branches || []}
+                  loading={isBranchesLoading}
                   createCustomValue
                   isClearable
                   {...field}
